@@ -11,7 +11,7 @@ def run():
         return
     b = bash("flake8 {0}".format(py_files.replace('\n', ' ')))
     if b.err:
-        if "command not found" in b.err:
+        if b"command not found" in b.err:
             return (
                 "flake8 is required for the flake8 plugin.\n"
                 "`pip install flake8` or turn it off in your tox.ini file.")
